﻿using System;
using System.Drawing;
using Dioada.ActiveFinish;
using Dioada.ActiveFinish.Elements;
using Dioada.ActiveFinish.Effects;

public class AfButton1 : Dioada.ActiveFinish.Controls.AFButton
{

    private System.ComponentModel.IContainer components;
    private LinearGradientRectangle elBackground;
    private DividerLine elLine;
    private TextGDIPlus elText;
    private ImagePlugin elImage;
    internal System.Windows.Forms.Timer ClickEffectTimer;
    internal System.Windows.Forms.Timer RolloverEffectTimer;

    private Water efWater;
    public AfButton1()
    {
        this.InitializeComponent();
        this.ClickEffectTimer.Tick += ClickEffectTimer_Tick;
        this.RolloverEffectTimer.Tick += RolloverEffectTimer_Tick;
    }

    // We're presetting the canvas, so we'll hide at design-time.
    [System.ComponentModel.Browsable(false), System.ComponentModel.DesignerSerializationVisibility(System.ComponentModel.DesignerSerializationVisibility.Hidden)]
    public override CanvasASO Canvas
    {
        get
        {
            return base.Canvas;
        }
    }

    protected override void OnHandleCreated(System.EventArgs e)
    {
        base.OnHandleCreated(e);

        Layer rootLayer = this.Canvas.RootLayer;
        this.elBackground = (LinearGradientRectangle)rootLayer.FindElementByName("background", true, true).Last;
        this.elLine = (DividerLine)rootLayer.FindElementByName("line", true, true).Last;
        this.elText = (TextGDIPlus)rootLayer.FindElementByName("text", true, true).Last;
        this.elImage = (ImagePlugin)rootLayer.FindElementByName("megaphone", true, true).Last;
        this.efWater = (Water)rootLayer.FindEffectByName("wobble", true, true).Last;

    }

    protected override void OnMouseEnter(System.EventArgs e)
    {
        base.OnMouseEnter(e);
        this.elImage.Tag = 1;
        this.elText.Enabled = true;
        this.RolloverEffectTimer.Start();
    }

    protected override void OnMouseLeave(System.EventArgs e)
    {
        base.OnMouseLeave(e);
        this.elImage.Tag = -1;
        this.elLine.Enabled = false;
        this.RolloverEffectTimer.Start();
    }

    protected override void OnClick(System.EventArgs e)
    {
        base.OnClick(e);
        if (this.ClickEffectTimer.Enabled)
        {
            this.ClickEffectTimer.Stop();
            this.efWater.Amount = 0f;
            this.efWater.Enabled = false;
            this.Canvas.RootLayer.Enabled = true;
            this.RefreshImage();
        }
        else
        {
            this.efWater.Amount = -20;
            this.efWater.Enabled = true;
            this.ClickEffectTimer.Start();
        }
    }

    // Creates the wobble effect.
    private void ClickEffectTimer_Tick(object sender, EventArgs e)
    {
        this.efWater.Amount += 4;
        if (this.efWater.Amount > 10)
        {
            this.efWater.Amount = 0;
            this.ClickEffectTimer.Enabled = false;
        }
        this.RefreshImage();
    }

    // Rotates and size the image & text elements, and draws the underline.

    private void RolloverEffectTimer_Tick(object sender, EventArgs e)
    {
        Dioada.ActiveFinish.Elements.ImagePlugin pic = this.elImage;

        // The image element tag contains either 1 or -1 depending on whether the timer was started from 
        // a mouse enter or leave event respectively.
        int i = Convert.ToInt32(pic.Tag);

        // Rotate and move the image element.
        float angle = pic.Angle;
        RectangleF bounds = pic.Bounds;
        angle += 6 * i;
        float x = bounds.X;
        float y = bounds.Y;
        float h = bounds.Height;
        float w = bounds.Width;
        x += 0.002f * i;
        y += 0.005f * i;
        w += 0.004f * i;
        h += 0.004f * i;
        pic.Angle = angle;
        pic.Bounds = new RectangleF(x, y, w, h);

        // Size and rotate the text element.
        PluginPath textPath = this.Canvas.RootLayer.FindElementByName("text", true, true);
        Canvas.AdjustElementSize(textPath, new SizeF(0.006f * i, 0.006f * i), ReSizeAnchor.Center);
        this.elText.Angle -= 6 * i;

        // Fade between straight and curved background corners.
        LinearGradientRectangle bg = this.elBackground;
        bg.BackColorAngle += 3 * i;
        bg.BorderRadius -= Convert.ToSingle(30 / 360) * 6 * i;

        // Draw the line when the effect is complete.
        if (angle % 360 == 0)
        {
            this.RolloverEffectTimer.Stop();
            if (i == -1)
            {
                this.elText.Enabled = false;
            }
            else
            {
                this.elLine.Enabled = true;
            }
        }

        this.RefreshImage();

    }

    private void InitializeComponent()
    {
        this.components = new System.ComponentModel.Container();
        Dioada.ActiveFinish.EffectSet effectSet1 = new Dioada.ActiveFinish.EffectSet();
        Dioada.ActiveFinish.Effects.Water water1 = new Dioada.ActiveFinish.Effects.Water();
        Dioada.ActiveFinish.Effects.Negative negative1 = new Dioada.ActiveFinish.Effects.Negative();
        Dioada.ActiveFinish.ElementSet elementSet1 = new Dioada.ActiveFinish.ElementSet();
        Dioada.ActiveFinish.Elements.LinearGradientRectangle linearGradientRectangle1 = new Dioada.ActiveFinish.Elements.LinearGradientRectangle();
        Dioada.ActiveFinish.Elements.DividerLine dividerLine1 = new Dioada.ActiveFinish.Elements.DividerLine();
        Dioada.ActiveFinish.Elements.TextGDIPlus alignableText1 = new Dioada.ActiveFinish.Elements.TextGDIPlus();
        Dioada.ActiveFinish.Elements.ImagePlugin imagePlugin1 = new Dioada.ActiveFinish.Elements.ImagePlugin();
        System.ComponentModel.ComponentResourceManager resources = new System.ComponentModel.ComponentResourceManager(typeof(AfButton1));
        this.RolloverEffectTimer = new System.Windows.Forms.Timer(this.components);
        this.ClickEffectTimer = new System.Windows.Forms.Timer(this.components);
        this.SuspendLayout();
        // 
        // RolloverEffectTimer
        // 
        this.RolloverEffectTimer.Interval = 1;
        // 
        // ClickEffectTimer
        // 
        this.ClickEffectTimer.Interval = 1;
        // 
        // AfButton1
        // 
        water1.Enabled = false;
        water1.Name = "wobble";
        effectSet1.Effects.AddRange(new Dioada.ActiveFinish.Effect[] {
            water1,
            negative1});
        this.Canvas.RootLayer.EffectSet = effectSet1;
        linearGradientRectangle1.BorderRadius = 30F;
        linearGradientRectangle1.BackColorAngle = 119F;
        linearGradientRectangle1.Name = "background";
        dividerLine1.Enabled = false;
        dividerLine1.Location = new Dioada.Drawing.SngPoint(0.6031746F, 0.7278911F);
        dividerLine1.Name = "line";
        dividerLine1.Size = new System.Drawing.SizeF(0.3015873F, 0.02721088F);
        alignableText1.AutoSize = false;
        alignableText1.Alignment = ContentAlignment.MiddleCenter;
        alignableText1.Enabled = false;
        alignableText1.Font = new System.Drawing.Font("Microsoft Sans Serif", 21.75F, System.Drawing.FontStyle.Regular, System.Drawing.GraphicsUnit.Point, ((byte)(0)));
        alignableText1.ForeColor = System.Drawing.SystemColors.ActiveCaption;
        alignableText1.Location = new Dioada.Drawing.SngPoint(0.7480159F, 0.5442177F);
        alignableText1.Name = "text";
        alignableText1.RenderingMode = System.Drawing.Text.TextRenderingHint.AntiAlias;
        alignableText1.Size = new System.Drawing.SizeF(0.01587302F, 0.02721088F);
        alignableText1.SizeWhenRasterized = new System.Drawing.Size(109, 82);
        alignableText1.Text = "Click me!";
        imagePlugin1.Location = new Dioada.Drawing.SngPoint(0.02183406F, -0.01030928F);
        imagePlugin1.Name = "megaphone";
        imagePlugin1.Size = new System.Drawing.SizeF(0.1091703F, 0.3195876F);
        imagePlugin1.Source.Image = ((System.Drawing.Image)(resources.GetObject("resource.Image")));
        elementSet1.Elements.AddRange(new Dioada.ActiveFinish.Element[] {
            linearGradientRectangle1,
            dividerLine1,
            alignableText1,
            imagePlugin1});
        this.Canvas.RootLayer.ElementSet = elementSet1;
        this.Canvas.RootLayer.SmoothingMode = Dioada.ActiveFinish.SmoothingMode.AntiAlias;
        this.Size = new System.Drawing.Size(260, 155);
        this.UseVisualStyleBackColor = true;
        this.ResumeLayout(false);

    }

}
