﻿using System;
using System.Drawing;
using Dioada.ActiveFinish;
using Dioada.ActiveFinish.Elements;
using Dioada.Drawing;

public partial class PaddleAndBall
{

    // Elements
    private LinearGradientRectangle elBackGround;
    private LinearGradientRectangle elPaddle;
    private LinearGradientEllipse elBall;
    private TextGDIPlus elTime;

    private TextGDIPlus elStartInfo;
    private bool MoveLeft;
    private bool MoveRight;
    private DateTime StartTime;
    private float BallSpeedX;
    private float BallSpeedY;

    private float PaddleSpeed;
    public PaddleAndBall()
    {
        InitializeComponent();
        AfButton1.KeyDown += AfButton1_KeyDown;
        AfButton1.KeyUp += AfButton1_KeyUp;
        tmrAnimation.Tick += TimerTick;

        ElementCollection elements = this.AfButton1.Canvas.RootLayer.Elements;
        this.elBackGround = (LinearGradientRectangle)elements[0];
        this.elStartInfo = (TextGDIPlus)elements[1];
        this.elTime = (TextGDIPlus)elements[2];
        this.elBall = (LinearGradientEllipse)elements[3];
        this.elPaddle = (LinearGradientRectangle)elements[4];

        this.elTime.Text = "";
        this.Reset();

    }

    protected override void OnHandleCreated(System.EventArgs e)
    {
        base.OnHandleCreated(e);
        this.MakeBallRound();
    }

    // Make sure the ball is always round.
    protected override void OnSizeChanged(System.EventArgs e)
    {
        base.OnSizeChanged(e);
        if (this.elBall != null)
        {
            this.MakeBallRound();
        }
    }

    private void MakeBallRound()
    {
        SizeF size = this.elBall.Size;
        Size containerSize = this.AfButton1.Canvas.Size;
        float w = (float)(containerSize.Width * 0.04f);
        this.elBall.SetAbsoluteSize(containerSize, new SizeF(w, w), Dioada.ActiveFinish.ReSizeAnchor.None);
    }

    // Check for X and Y key presses.
    private void AfButton1_KeyDown(object sender, System.Windows.Forms.KeyEventArgs kevent)
    {
        if (kevent.KeyCode == System.Windows.Forms.Keys.Z)
        {
            this.MoveLeft = true;
        }
        else if (kevent.KeyCode == System.Windows.Forms.Keys.X)
        {
            this.MoveRight = true;
        }
        base.OnKeyDown(kevent);
    }

    private void AfButton1_KeyUp(object sender, System.Windows.Forms.KeyEventArgs kevent)
    {
        this.MoveLeft = false;
        this.MoveRight = false;
        base.OnKeyUp(kevent);
    }

    // Start/ Stop the game when the button is clicked.
    private void AfButton1_Click(System.Object sender, System.EventArgs e)
    {
        base.OnClick(e);
        if (this.tmrAnimation.Enabled)
        {
            this.tmrAnimation.Enabled = false;
        }
        else
        {
            this.StartTime = DateTime.Now;
            this.elTime.Text = "";
            this.elStartInfo.Enabled = false;
            this.tmrAnimation.Enabled = true;
        }
    }

    // The tick event that moves the ball and paddle.

    private void TimerTick(object sender, EventArgs e)
    {
        LinearGradientEllipse ball = this.elBall;
        Dioada.Drawing.SngPoint loc = ball.Location;
        float ballX = loc.X;
        float ballY = loc.Y;
        ballX += BallSpeedX;
        ballY += BallSpeedY;
        ball.Location = new SngPoint(ballX, ballY);

        Size containerSize = this.AfButton1.Canvas.Size;
        RectangleF b1 = ball.GetAbsoluteBounds(containerSize);
        RectangleF b2 = this.elPaddle.GetAbsoluteBounds(containerSize);
        
        if (b1.Bottom >= b2.Top)
        {
            if (b1.Right >= b2.Left && b1.Left <= b2.Right)
            {
                BallSpeedY *= -1;
                ballY += BallSpeedY;
            }
            else
            {
                this.Reset();
                this.tmrAnimation.Stop();
                return;
            }


        }
        else
        {
            if (ballX > 1f)
            {
                ballX = 1f;
                BallSpeedX *= -1;
            }
            else if (ballX < 0f)
            {
                ballX = 0f;
                BallSpeedX *= -1;
            }

            if (ballY < 0f)
            {
                ballY = 0f;
                BallSpeedY *= -1;
            }

        }

        ball.BackColorAngle += BallSpeedX > 0 ? 5 : -5;
        ball.Location = new SngPoint(ballX, ballY);

        LinearGradientRectangle p = this.elPaddle;
        if (this.MoveLeft)
        {
            p.Location = new SngPoint(p.Location.X - PaddleSpeed, p.Location.Y);
        }
        else if (this.MoveRight)
        {
            p.Location = new SngPoint(p.Location.X + PaddleSpeed, p.Location.Y);
        }

        TimeSpan ts = DateTime.Now - this.StartTime;
        this.elTime.Text = string.Format("{0}:{1}.{2}", ts.Minutes, ts.Seconds, ts.Milliseconds);

        this.AfButton1.RefreshImage();

        BallSpeedX *= 1.0001f;
        BallSpeedY *= 1.0001f;
        PaddleSpeed *= 1.0001f;

    }

    private void Reset()
    {
        this.elBall.Location = new SngPoint(0.5f, 0f);
        this.elPaddle.Location = new SngPoint(0.4f, 0.92f);
        this.BallSpeedX = 0.01f;
        this.BallSpeedY = 0.007f;
        this.PaddleSpeed = 0.01f;
        this.elStartInfo.Enabled = true;
        this.AfButton1.RefreshImage();
    }

}
