﻿using System;
using System.Windows.Forms;
using Dioada.ActiveFinish;
using Dioada.ActiveFinish.Elements;

public partial class VideoPlayerDemo
{

    private VideoPlayerBeta Player = null;
    private Effect SelectedEffect = null;

    private ToolStripMenuItem SelectedMenuItem = null;
    public VideoPlayerDemo()
    {
        InitializeComponent();

        this.Player = (VideoPlayerBeta)this.AfButton1.Canvas.RootLayer.FindFirstElementByType(typeof(VideoPlayerBeta), true).Last;

        ToolStripItemCollection items = this.mnuEffects.DropDownItems;
        foreach (ToolStripItem item in items)
        {
            ToolStripMenuItem item2 = item as ToolStripMenuItem;
            if (item2 != null)
            {
                item2.Click += EffectSelected;
            }
        }

        this.mnuPlay.Click += PlayClick;
        this.mnuPause.Click += PauseClick;
        this.mnuRewind.Click += RewindClick;
        this.AfButton1.Click += ButtonClick;
        this.Timer1.Tick += TimerTick;

        this.SelectedMenuItem = this.NoneToolStripMenuItem;

    }

    private void ButtonClick(object sender, EventArgs e)
    {
        if (!(this.Player.State == Dioada.DirectShow.PlayerState.Playing))
        {
            this.Play();
        }
        else
        {
            this.Pause();
        }
    }

    private void PlayClick(object sender, EventArgs e)
    {
        this.Play();
    }

    private void PauseClick(object sender, EventArgs e)
    {
        this.Pause();
    }

    private void RewindClick(object sender, EventArgs e)
    {
        this.Player.RewindToStart();
    }


    private void EffectSelected(object sender, EventArgs e)
    {
        
        ToolStripMenuItem item = (ToolStripMenuItem)sender;
        string effectName = (string)(item.Tag);
        if (effectName == "sunonscreen")
        {
            this.mnuSunOnScreen.Checked = !this.mnuSunOnScreen.Checked;
            Plugin screen = this.AfButton1.Canvas.RootLayer.FindElementByName("tvscreen", true, true).Last;
            screen.Enabled = !screen.Enabled;
            return;
        }

        if (this.SelectedEffect != null)
        {
            this.SelectedEffect.Enabled = false;
        }
        this.SelectedMenuItem.Checked = false;

        this.SelectedMenuItem = item;
        item.Checked = true;

        this.Timer1.Stop();
        Layer rootLayer = this.AfButton1.Canvas.RootLayer;
        rootLayer.Angle = 0;
        rootLayer.Size = new System.Drawing.SizeF(1f, 1f);
        rootLayer.Location = new Dioada.Drawing.SngPoint(0f, 0f);

        if (effectName == "rotateandsize")
        {
            this.Timer1.Start();
        }
        else if (effectName != "none")
        {
            Effect effect = (Effect)this.AfButton1.Canvas.RootLayer.FindEffectByName(effectName, true, true).Last;
            effect.Enabled = true;
            this.SelectedEffect = effect;
        }

        Plugin photo = this.AfButton1.Canvas.RootLayer.FindElementByName("sunoverocean", true, true).Last;
        photo.Enabled = (effectName == "opacity");

        photo = this.AfButton1.Canvas.RootLayer.FindElementByName("turtle", true, true).Last;
        photo.Enabled = (effectName == "colorextractor");

        this.AfButton1.RefreshImage();

    }


    private void TimerTick(object sender, EventArgs e)
	{
		int min = 100;
		int max = 200;
		int div = 10000;
		float wOffset = 0;
		float hOffset = 0;

		object data = this.Timer1.Tag;
		if (data != null) {
			string[] ar = ((string)data).Split(',');
			wOffset = Convert.ToSingle(ar[0]);
			hOffset = Convert.ToSingle(ar[1]);
		} else {
            Random r = new Random(DateTime.Now.Millisecond);
            wOffset = (float)(((double)r.Next(min, max)) / ((double)div));
            r = new Random();
            hOffset = (float)(((double)r.Next(min, max)) / ((double)div));
		}

		Layer l = this.AfButton1.Canvas.RootLayer;

		float w = l.Width;
		float h = l.Height;
		l.Angle += 2;

		w += wOffset;
		if (w < 0.05f) {
			w = 0.05f;
            Random r = new Random(DateTime.Now.Millisecond);
            wOffset = (float)(((double)r.Next(min, max)) / ((double)div));
		} else if (w > 1f) {
			w = 1f;
            Random r = new Random(DateTime.Now.Millisecond);
            wOffset = -((float)(((double)r.Next(min, max)) / ((double)div)));
		}

		h += hOffset;
		if (h < 0.05f) {
			h = 0.05f;
            Random r = new Random();
            hOffset = (float)(((double)r.Next(min, max)) / ((double)div));
		} else if (h > 1f) {
			h = 1f;
            Random r = new Random();
            hOffset = -((float)(((double)r.Next(min, max)) / ((double)div)));
		}

		l.SetSize(this.AfButton1.Canvas.Size, new System.Drawing.SizeF(w, h), ReSizeAnchor.Center);

		this.AfButton1.RefreshImage();

		this.Timer1.Tag = wOffset.ToString() + "," + hOffset.ToString();
	}

    private void Play()
    {
        Plugin button = this.AfButton1.Canvas.RootLayer.FindElementByName("playbutton", true, true).Last;
        button.Enabled = false;
        this.Player.Start();
    }

    private void Pause()
    {
        this.Player.Pause();
        Plugin button = this.AfButton1.Canvas.RootLayer.FindElementByName("playbutton", true, true).Last;
        button.Enabled = true;
        this.AfButton1.RefreshImage();
    }

}
