﻿Imports Dioada.ActiveFinish

Public Class AfButton1
    Inherits Dioada.ActiveFinish.Controls.AFButton

    Private components As System.ComponentModel.IContainer
    Private elBackground As Elements.LinearGradientRectangle
    Private elLine As Elements.DividerLine
    Private elText As Elements.TextGDIPlus
    Private elImage As Elements.ImagePlugin
    Friend ClickEffectTimer As System.Windows.Forms.Timer
    Friend RolloverEffectTimer As System.Windows.Forms.Timer
    Private efWater As Effects.Water

    Public Sub New()
        Me.InitializeComponent()
        AddHandler Me.ClickEffectTimer.Tick, AddressOf ClickEffectTimer_Tick
        AddHandler Me.RolloverEffectTimer.Tick, AddressOf RolloverEffectTimer_Tick
    End Sub

    ' We're presetting the canvas, so we'll hide at design-time.
    <Browsable(False), DesignerSerializationVisibility(DesignerSerializationVisibility.Hidden)> _
    Public Overrides ReadOnly Property Canvas() As Dioada.ActiveFinish.CanvasASO
        Get
            Return MyBase.Canvas
        End Get
    End Property

    Protected Overrides Sub OnHandleCreated(ByVal e As System.EventArgs)
        MyBase.OnHandleCreated(e)

        Dim rootLayer = Me.Canvas.RootLayer
        Me.elBackground = DirectCast(rootLayer.FindElementByName("background", True, True).Last, Elements.LinearGradientRectangle)
        Me.elLine = DirectCast(rootLayer.FindElementByName("line", True, True).Last, Elements.DividerLine)
        Me.elText = DirectCast(rootLayer.FindElementByName("text", True, True).Last, Elements.TextGDIPlus)
        Me.elImage = DirectCast(rootLayer.FindElementByName("megaphone", True, True).Last, Elements.ImagePlugin)
        Me.efWater = DirectCast(rootLayer.FindEffectByName("wobble", True, True).Last, Effects.Water)

    End Sub

    Protected Overrides Sub OnMouseEnter(ByVal e As System.EventArgs)
        MyBase.OnMouseEnter(e)
        Me.elImage.Tag = 1
        Me.elText.Enabled = True
        Me.RolloverEffectTimer.Start()
    End Sub

    Protected Overrides Sub OnMouseLeave(ByVal e As System.EventArgs)
        MyBase.OnMouseLeave(e)
        Me.elImage.Tag = -1
        Me.elLine.Enabled = False
        Me.RolloverEffectTimer.Start()
    End Sub

    Protected Overrides Sub OnClick(ByVal e As System.EventArgs)
        MyBase.OnClick(e)
        If Me.ClickEffectTimer.Enabled Then
            Me.ClickEffectTimer.Stop()
            Me.efWater.Amount = 0.0!
            Me.efWater.Enabled = False
            Me.Canvas.RootLayer.Enabled = True
            Me.RefreshImage()
        Else
            Me.efWater.Amount = -20
            Me.efWater.Enabled = True
            Me.ClickEffectTimer.Start()
        End If
    End Sub

    ' Creates the wobble effect.
    Private Sub ClickEffectTimer_Tick(ByVal sender As Object, ByVal e As EventArgs)
        Me.efWater.Amount += 4
        If Me.efWater.Amount > 10 Then
            Me.efWater.Amount = 0
            Me.ClickEffectTimer.Enabled = False
        End If
        Me.RefreshImage()
    End Sub

    ' Rotates and size the image & text elements, and draws the underline.
    Private Sub RolloverEffectTimer_Tick(ByVal sender As Object, ByVal e As EventArgs)

        Dim pic = Me.elImage

        ' The image element tag contains either 1 or -1 depending on whether the timer was started from 
        ' a mouse enter or leave event respectively.
        Dim i As Integer = CInt(pic.Tag)

        ' Rotate and move the image element.
        Dim angle As Single = pic.Angle
        Dim bounds As RectangleF = pic.Bounds
        angle += 6 * i
        Dim x = bounds.X
        Dim y = bounds.Y
        Dim h = bounds.Height
        Dim w = bounds.Width
        x += 0.002! * i
        y += 0.005! * i
        w += 0.004! * i
        h += 0.004! * i
        pic.Angle = angle
        pic.Bounds = New RectangleF(x, y, w, h)

        ' Size and rotate the text element.
        Dim textPath = Me.Canvas.RootLayer.FindElementByName("text", True, True)
        Canvas.AdjustElementSize(textPath, New SizeF(0.006! * i, 0.006! * i), ReSizeAnchor.Center)
        Me.elText.Angle -= 6 * i

        ' Fade between straight and curved background corners.
        Dim bg = Me.elBackground
        bg.BackColorAngle += 3 * i
        bg.BorderRadius -= CSng(30 / 360) * 6 * i

        ' Draw the line when the effect is complete.
        If angle Mod 360 = 0 Then
            Me.RolloverEffectTimer.Stop()
            If i = -1 Then
                Me.elText.Enabled = False
            Else
                Me.elLine.Enabled = True
            End If
        End If

        Me.RefreshImage()

    End Sub

    Private Sub InitializeComponent()
        Me.components = New System.ComponentModel.Container
        Dim EffectSet1 As Dioada.ActiveFinish.EffectSet = New Dioada.ActiveFinish.EffectSet
        Dim Water1 As Dioada.ActiveFinish.Effects.Water = New Dioada.ActiveFinish.Effects.Water
        Dim Negative1 As Dioada.ActiveFinish.Effects.Negative = New Dioada.ActiveFinish.Effects.Negative
        Dim ElementSet1 As Dioada.ActiveFinish.ElementSet = New Dioada.ActiveFinish.ElementSet
        Dim LinearGradientRectangle1 As Dioada.ActiveFinish.Elements.LinearGradientRectangle = New Dioada.ActiveFinish.Elements.LinearGradientRectangle
        Dim DividerLine1 As Dioada.ActiveFinish.Elements.DividerLine = New Dioada.ActiveFinish.Elements.DividerLine
        Dim TextGDIPlus1 As Dioada.ActiveFinish.Elements.TextGDIPlus = New Dioada.ActiveFinish.Elements.TextGDIPlus
        Dim ImagePlugin1 As Dioada.ActiveFinish.Elements.ImagePlugin = New Dioada.ActiveFinish.Elements.ImagePlugin
        Dim resources As System.ComponentModel.ComponentResourceManager = New System.ComponentModel.ComponentResourceManager(GetType(AfButton1))
        Me.RolloverEffectTimer = New System.Windows.Forms.Timer(Me.components)
        Me.ClickEffectTimer = New System.Windows.Forms.Timer(Me.components)
        Me.SuspendLayout()
        '
        'RolloverEffectTimer
        '
        Me.RolloverEffectTimer.Interval = 1
        '
        'ClickEffectTimer
        '
        Me.ClickEffectTimer.Interval = 1
        '
        'AfButton1
        '
        Water1.Enabled = False
        Water1.Name = "wobble"
        EffectSet1.Effects.AddRange(New Dioada.ActiveFinish.Effect() {Water1, Negative1})
        Me.Canvas.RootLayer.EffectSet = EffectSet1
        LinearGradientRectangle1.BorderRadius = 30.0!
        LinearGradientRectangle1.BackColorAngle = 119.0!
        LinearGradientRectangle1.Name = "background"
        DividerLine1.Enabled = False
        DividerLine1.Location = New Dioada.Drawing.SngPoint(0.6031746!, 0.7278911!)
        DividerLine1.Name = "line"
        DividerLine1.Size = New System.Drawing.SizeF(0.3015873!, 0.02721088!)
        TextGDIPlus1.Alignment = System.Drawing.ContentAlignment.MiddleCenter
        TextGDIPlus1.AutoSize = False
        TextGDIPlus1.Enabled = False
        TextGDIPlus1.Font = New System.Drawing.Font("Microsoft Sans Serif", 21.75!, System.Drawing.FontStyle.Regular, System.Drawing.GraphicsUnit.Point, CType(0, Byte))
        TextGDIPlus1.ForeColor = System.Drawing.SystemColors.ActiveCaption
        TextGDIPlus1.Location = New Dioada.Drawing.SngPoint(0.7480159!, 0.5442177!)
        TextGDIPlus1.Name = "text"
        TextGDIPlus1.RenderingMode = System.Drawing.Text.TextRenderingHint.AntiAlias
        TextGDIPlus1.Size = New System.Drawing.SizeF(0.01587302!, 0.02721088!)
        TextGDIPlus1.SizeWhenRasterized = New System.Drawing.Size(109, 82)
        TextGDIPlus1.Text = "Click me!"
        ImagePlugin1.Location = New Dioada.Drawing.SngPoint(0.02183406!, -0.01030928!)
        ImagePlugin1.Name = "megaphone"
        ImagePlugin1.Size = New System.Drawing.SizeF(0.1091703!, 0.3195876!)
        ImagePlugin1.Source.Image = CType(resources.GetObject("resource.Image"), System.Drawing.Image)
        ElementSet1.Elements.AddRange(New Dioada.ActiveFinish.Element() {LinearGradientRectangle1, DividerLine1, TextGDIPlus1, ImagePlugin1})
        Me.Canvas.RootLayer.ElementSet = ElementSet1
        Me.Canvas.RootLayer.SmoothingMode = Dioada.ActiveFinish.SmoothingMode.AntiAlias
        Me.Size = New System.Drawing.Size(260, 155)
        Me.UseVisualStyleBackColor = True
        Me.ResumeLayout(False)

    End Sub

End Class
