﻿Imports Dioada.ActiveFinish.Elements
Imports Dioada.Drawing

Public Class PaddleAndBall

    ' Elements
    Private elBackGround As LinearGradientRectangle
    Private elPaddle As LinearGradientRectangle
    Private elBall As LinearGradientEllipse
    Private elTime As TextGDIPlus
    Private elStartInfo As TextGDIPlus

    Private MoveLeft, MoveRight As Boolean
    Private StartTime As DateTime
    Private BallSpeedX, BallSpeedY, PaddleSpeed As Single

    Public Sub New()
        InitializeComponent()
        Dim elements = Me.AfButton1.Canvas.RootLayer.Elements
        Me.elBackGround = DirectCast(elements(0), LinearGradientRectangle)
        Me.elStartInfo = DirectCast(elements(1), TextGDIPlus)
        Me.elTime = DirectCast(elements(2), TextGDIPlus)
        Me.elBall = DirectCast(elements(3), LinearGradientEllipse)
        Me.elPaddle = DirectCast(elements(4), LinearGradientRectangle)

        Me.elTime.Text = ""
        Me.Reset()

    End Sub

    Protected Overrides Sub OnHandleCreated(ByVal e As System.EventArgs)
        MyBase.OnHandleCreated(e)
        Me.MakeBallRound()
    End Sub

    ' Make sure the ball is always round.
    Protected Overrides Sub OnSizeChanged(ByVal e As System.EventArgs)
        MyBase.OnSizeChanged(e)
        If Me.elBall IsNot Nothing Then
            Me.MakeBallRound()
        End If
    End Sub

    Private Sub MakeBallRound()
        Dim size = Me.elBall.Size
        Dim containerSize = Me.AfButton1.Canvas.Size
        Dim w = CSng(containerSize.Width * 0.04!)
        Me.elBall.SetAbsoluteSize(containerSize, New SizeF(w, w), Dioada.ActiveFinish.ReSizeAnchor.None)
    End Sub

    ' Check for X and Y key presses.
    Private Sub AfButton1_KeyDown(ByVal sender As Object, ByVal kevent As System.Windows.Forms.KeyEventArgs) Handles AfButton1.KeyDown
        If kevent.KeyCode = Keys.Z Then
            Me.MoveLeft = True
        ElseIf kevent.KeyCode = Keys.X Then
            Me.MoveRight = True
        End If
        MyBase.OnKeyDown(kevent)
    End Sub

    Private Sub AfButton1_KeyUp(ByVal sender As Object, ByVal kevent As System.Windows.Forms.KeyEventArgs) Handles AfButton1.KeyUp
        Me.MoveLeft = False
        Me.MoveRight = False
        MyBase.OnKeyUp(kevent)
    End Sub

    ' Start/ Stop the game when the button is clicked.
    Private Sub AfButton1_Click(ByVal sender As System.Object, ByVal e As System.EventArgs) Handles AfButton1.Click
        MyBase.OnClick(e)
        If Me.tmrAnimation.Enabled Then
            Me.tmrAnimation.Enabled = False
        Else
            Me.StartTime = Now
            Me.elTime.Text = ""
            Me.elStartInfo.Enabled = False
            Me.tmrAnimation.Enabled = True
        End If
    End Sub

    ' The tick event that moves the ball and paddle.
    Private Sub TimerTick(ByVal sender As Object, ByVal e As EventArgs) Handles tmrAnimation.Tick

        Dim ball = Me.elBall
        Dim loc = ball.Location
        Dim ballX = loc.X
        Dim ballY = loc.Y
        ballX += BallSpeedX
        ballY += BallSpeedY
        ball.Location = New SngPoint(ballX, ballY)

        Dim containerSize = Me.AfButton1.Canvas.Size
        Dim b1 = ball.GetAbsoluteBounds(containerSize)
        Dim b2 = Me.elPaddle.GetAbsoluteBounds(containerSize)

        If b1.Bottom >= b2.Top Then

            If b1.Right >= b2.Left AndAlso b1.Left <= b2.Right Then
                BallSpeedY *= -1
                ballY += BallSpeedY
            Else
                Me.Reset()
                Me.tmrAnimation.Stop()
                Exit Sub
            End If

        Else

            If ballX > 1.0! Then
                ballX = 1.0!
                BallSpeedX *= -1
            ElseIf ballX < 0.0! Then
                ballX = 0.0!
                BallSpeedX *= -1
            End If

            If ballY < 0.0! Then
                ballY = 0.0!
                BallSpeedY *= -1
            End If

        End If

        ball.BackColorAngle += If(BallSpeedX > 0, 5, -5)
        ball.Location = New SngPoint(ballX, ballY)

        Dim p = Me.elPaddle
        If Me.MoveLeft Then
            p.Location = New SngPoint(p.Location.X - PaddleSpeed, p.Location.Y)
        ElseIf Me.MoveRight Then
            p.Location = New SngPoint(p.Location.X + PaddleSpeed, p.Location.Y)
        End If

        Dim ts As TimeSpan = Now - Me.StartTime
        Me.elTime.Text = String.Format("{0}:{1}.{2}", ts.Minutes, ts.Seconds, ts.Milliseconds)

        Me.AfButton1.RefreshImage()

        BallSpeedX *= 1.0001!
        BallSpeedY *= 1.0001!
        PaddleSpeed *= 1.0001!

    End Sub

    Private Sub Reset()
        Me.elBall.Location = New SngPoint(0.5!, 0.0!)
        Me.elPaddle.Location = New SngPoint(0.4!, 0.92!)
        Me.BallSpeedX = 0.01!
        Me.BallSpeedY = 0.007!
        Me.PaddleSpeed = 0.01!
        Me.elStartInfo.Enabled = True
        Me.AfButton1.RefreshImage()
    End Sub

End Class